/*
 * Upravte tento súbor a uložte ho pod názvom userContent.css do popriečinka chrome 
 * v priečinku s používateľským profilom.
 */

/*
 * Tento súbor sa používa na nastavenie vzhľadu používateľského 
 * rozhrania produktov Mozilly. Pravidlá s deklaráciou !important majú prednosť pred 
 * predvoleným nastavením.
 */
  
/*
 * Neodstraňujte riadok @namespace – je potrebný pre správnu funkčnosť
 */
@namespace url("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul"); /* nastaví predvolený priestor názvov na XUL */


/*
 * Niektoré možné vylepšenia:
 */
/*
 * Nastavenie predvolenej veľkosti písma na 20 pt:
 *
 * * {
 *   font-size: 20pt !important
 * }
 */
 /*
 * Nastavenie písma v ponuke na 15 pt namiesto predvolenej veľkosti:
 *  
 * menupopup > * {
 *  font-size: 15pt !important 
 * }
 */
/*
 * Zmena písma v paneli s adresou na písmo s pevnou šírkou znakov
 *  
 * #urlbar {
 *  font-family: monospace !important;
 * }
 */
  
/*
 * Ďalšie príklady nájdete na http://www.mozilla.org/unix/customizing.html
 */
 
