/*
 * Upravte tento súbor a uložte ho pod názvom userContent.css do podpriečinka chrome 
 * v priečinku s používateľským profilom.
 */
 
/*
 * Tento súbor sa používa na nastavenie používateľských kaskádových štýlov
 * na webových stránkach. Pravidlá bez deklarácie !important budú prepísané
 * kaskádovými štýlmi webovej stránky, pokiaľ také existujú. Pravidlá s 
 * deklaráciou !important majú prednosť pred pravidlami na webovej stránke.
 */
 
/*
 * príklad: odstránenie blikania pre prvok "blink"
 *
 * blink { text-decoration: none !important; }
 *
 */
 
/*
 * príklad: nastavenie orámovania so šírkou 2px pre všetky tabuľky
 *
 * table { border: 2px solid; }
 *
 */
 
/*
 * príklad: vypnutie prvku "marquee"
 *
 * marquee { -moz-binding: none; }
 *
 */

/*
 * Ďalšie príklady nájdete na http://www.mozilla.org/unix/customizing.html
 */

